@@ -1,7 +1,8 @@
 #!/usr/bin/env python
 
 import numpy as np
-from roboticstoolbox.robot.ERobot import ERobot
+from roboticstoolbox.robot.ERobot import ERobot, ERobot2
+from spatialmath import SE3
 
 
 class Panda(ERobot):
@@ -28,29 +29,40 @@ class Panda(ERobot):
     .. codeauthor:: Jesse Haviland
     .. sectionauthor:: Peter Corke
     """
+
     def __init__(self):
 
-        elinks, name = super().urdf_to_ets_args(
-            "franka_description/robots/panda_arm_hand.urdf.xacro")
-
-        super().__init__(
-            elinks,
-            name=name,
-            manufacturer='Franka Emika',
-            gripper_links=elinks[9]
+        links, name, urdf_string, urdf_filepath = self.URDF_read(
+            "franka_description/robots/panda_arm_hand.urdf.xacro"
         )
 
-        self.qdlim = np.array([
-            2.1750, 2.1750, 2.1750, 2.1750, 2.6100, 2.6100, 2.6100, 3.0, 3.0])
+        super().__init__(
+            links,
+            name=name,
+            manufacturer="Franka Emika",
+            gripper_links=links[9],
+            urdf_string=urdf_string,
+            urdf_filepath=urdf_filepath,
+        )
 
-        self.addconfiguration("qz", np.array(
-            [0, 0, 0, 0, 0, 0, 0]))
+        self.grippers[0].tool = SE3(0, 0, 0.1034)
 
-        self.addconfiguration("qr", np.array(
-            [0, -0.3, 0, -2.2, 0, 2.0, np.pi/4]))
+        self.qdlim = np.array(
+            [2.1750, 2.1750, 2.1750, 2.1750, 2.6100, 2.6100, 2.6100, 3.0, 3.0]
+        )
+
+        self.qr = np.array([0, -0.3, 0, -2.2, 0, 2.0, np.pi / 4])
+        self.qz = np.zeros(7)
+
+        self.addconfiguration("qr", self.qr)
+        self.addconfiguration("qz", self.qz)
 
 
-if __name__ == '__main__':   # pragma nocover
+if __name__ == "__main__":  # pragma nocover
 
-    robot = Panda()
-    print(robot)
+    r = Panda()
+
+    r.qz
+
+    for link in r.grippers[0].links:
+        print(link)
