@@ -29,25 +29,29 @@ class px100(ERobot):
     .. codeauthor:: Jesse Haviland
     .. sectionauthor:: Peter Corke
     """
+
     def __init__(self):
 
-        links, name = self.URDF_read(
-            "interbotix_descriptions/urdf/px100.urdf.xacro")
+        links, name, urdf_string, urdf_filepath = self.URDF_read(
+            "interbotix_descriptions/urdf/px100.urdf.xacro"
+        )
 
         super().__init__(
-                links,
-                name=name,
-                manufacturer='Interbotix'
-            )
+            links,
+            name=name,
+            manufacturer="Interbotix",
+            urdf_string=urdf_string,
+            urdf_filepath=urdf_filepath,
+        )
 
-        self.addconfiguration(
-            "qz", np.array([0, 0, 0, 0, 0, 0, 0]))
-        self.addconfiguration(
-            "qr", np.array([0, -0.3, 0, -2.2, 0, 2.0, np.pi/4]))
+        self.qr = np.array([0, -0.3, 0, -2.2, 0, 2.0, np.pi / 4])
+        self.qz = np.zeros(7)
+
+        self.addconfiguration("qr", self.qr)
+        self.addconfiguration("qz", self.qz)
 
 
-if __name__ == '__main__':   # pragma nocover
+if __name__ == "__main__":  # pragma nocover
 
     robot = px100()
     print(robot)
-    robot.dynamics()
